@@ -9,8 +9,9 @@
 #
 package MooseX::Attribute::LazyInflator;
 BEGIN {
-  $MooseX::Attribute::LazyInflator::VERSION = '2.0.1';
+  $MooseX::Attribute::LazyInflator::VERSION = '2.1.0';
 }
+
 # ABSTRACT: Deflates and inflates Moose attributes to and from a string
 
 use Moose();
@@ -18,29 +19,28 @@ use MooseX::Attribute::Deflator ();
 use Moose::Exporter;
 use Moose::Util ();
 use MooseX::Attribute::LazyInflator::Meta::Role::Attribute;
-Moose::Exporter->setup_import_methods;
-
-sub init_meta {
-      shift;
-      my %args = @_;
-
-      Moose->init_meta(%args);
-
-      Moose::Util::MetaRole::apply_metaroles(
-          for             => $args{for_class},
-          class_metaroles => {
-              constructor => ['MooseX::Attribute::LazyInflator::Meta::Role::Method::Constructor'],
-          },
-      ) if Moose->VERSION < 1.9900;
-
-      Moose::Util::apply_all_roles($args{for_class}, 'MooseX::Attribute::LazyInflator::Role::Class');
-
-      return $args{for_class}->meta;
-}
-
-Moose::Util::_create_alias('Attribute', 'LazyInflator', 1, 'MooseX::Attribute::LazyInflator::Meta::Role::Attribute');
+use MooseX::Attribute::LazyInflator::Meta::Role::ApplicationToClass;
+use MooseX::Attribute::LazyInflator::Meta::Role::ApplicationToRole;
 
+Moose::Exporter->setup_import_methods(
+    Moose->VERSION < 1.9900
+    ? (
+        class_metaroles => {
+            constructor => [
+'MooseX::Attribute::LazyInflator::Meta::Role::Method::Constructor'
+            ],
+        } )
+    : (),
+    role_metaroles => {
+          application_to_class =>
+            ['MooseX::Attribute::LazyInflator::Meta::Role::ApplicationToClass'],
+          application_to_role =>
+            ['MooseX::Attribute::LazyInflator::Meta::Role::ApplicationToRole'],
+    },
+    base_class_roles => ['MooseX::Attribute::LazyInflator::Role::Class'] );
 
+Moose::Util::_create_alias( 'Attribute', 'LazyInflator', 1,
+                     'MooseX::Attribute::LazyInflator::Meta::Role::Attribute' );
 
 1;
 
@@ -54,7 +54,7 @@ MooseX::Attribute::LazyInflator - Deflates and inflates Moose attributes to and
 
 =head1 VERSION
 
-version 2.0.1
+version 2.1.0
 
 =head1 SYNOPSIS
 
